( cd lib ; rm -rf ld-linux.so.1 )
( cd lib ; ln -sf ld-linux.so.1.7.3 ld-linux.so.1 )
( cd lib ; rm -rf libdl.so.1 )
( cd lib ; ln -sf libdl.so.1.7.3 libdl.so.1 )
( cd lib ; rm -rf libdl.so )
( cd lib ; ln -sf libdl.so.1 libdl.so )
